﻿using Infrastructure;
using Infrastructure.Attribute;
using Infrastructure.Enums;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using ZR.Model.Dto;
using ZR.Model.Models;
using ZR.Service.Business.IBusinessService;
using ZR.Admin.WebApi.Extensions;
using ZR.Admin.WebApi.Filters;
using ZR.Common;

namespace ZR.Admin.WebApi.Controllers
{
    /// <summary>
    /// 出库管理/出库记录表Controller
    /// 
    /// @tableName out_outstore_record
    /// @author admin
    /// @date 2023-04-18
    /// </summary>
    [Verify]
    [Route("business/OutOutstoreRecord")]
    public class OutOutstoreRecordController : BaseController
    {
        /// <summary>
        /// 出库管理/出库记录表接口
        /// </summary>
        private readonly IOutOutstoreRecordService _OutOutstoreRecordService;

        public OutOutstoreRecordController(IOutOutstoreRecordService OutOutstoreRecordService)
        {
            _OutOutstoreRecordService = OutOutstoreRecordService;
        }

        /// <summary>
        /// 查询出库管理/出库记录表列表
        /// </summary>
        /// <param name="parm"></param>
        /// <returns></returns>
        [HttpGet("list")]
        [ActionPermissionFilter(Permission = "business:outoutstorerecord:list")]
        public IActionResult QueryOutOutstoreRecord([FromQuery] OutOutstoreRecordQueryDto parm)
        {
            var response = _OutOutstoreRecordService.GetList(parm);
            return SUCCESS(response);
        }


        /// <summary>
        /// 查询出库管理/出库记录表详情
        /// </summary>
        /// <param name="OutStoreId"></param>
        /// <returns></returns>
        [HttpGet("{OutStoreId}")]
        [ActionPermissionFilter(Permission = "business:outoutstorerecord:query")]
        public IActionResult GetOutOutstoreRecord(int OutStoreId)
        {
            var response = _OutOutstoreRecordService.GetFirst(x => x.OutStoreId == OutStoreId);

            return SUCCESS(response);
        }

        /// <summary>
        /// 添加出库管理/出库记录表
        /// </summary>
        /// <returns></returns>
        [HttpPost]
        [ActionPermissionFilter(Permission = "business:outoutstorerecord:add")]
        [Log(Title = "出库管理/出库记录表", BusinessType = BusinessType.INSERT)]
        public IActionResult AddOutOutstoreRecord([FromBody] OutOutstoreRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求参数错误");
            }
            var modal = parm.Adapt<OutOutstoreRecord>().ToCreate(HttpContext);

            var response = _OutOutstoreRecordService.AddOutOutstoreRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 更新出库管理/出库记录表
        /// </summary>
        /// <returns></returns>
        [HttpPut]
        [ActionPermissionFilter(Permission = "business:outoutstorerecord:edit")]
        [Log(Title = "出库管理/出库记录表", BusinessType = BusinessType.UPDATE)]
        public IActionResult UpdateOutOutstoreRecord([FromBody] OutOutstoreRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求实体不能为空");
            }
            var modal = parm.Adapt<OutOutstoreRecord>().ToUpdate(HttpContext);

            var response = _OutOutstoreRecordService.UpdateOutOutstoreRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 删除出库管理/出库记录表
        /// </summary>
        /// <returns></returns>
        [HttpDelete("{ids}")]
        [ActionPermissionFilter(Permission = "business:outoutstorerecord:delete")]
        [Log(Title = "出库管理/出库记录表", BusinessType = BusinessType.DELETE)]
        public IActionResult DeleteOutOutstoreRecord(string ids)
        {
            int[] idsArr = Tools.SpitIntArrary(ids);
            if (idsArr.Length <= 0) { return ToResponse(ApiResult.Error($"删除失败Id 不能为空")); }

            var response = _OutOutstoreRecordService.Delete(idsArr);

            return ToResponse(response);
        }



    }
}