﻿using System;
using SqlSugar;
using Infrastructure.Attribute;
using ZR.Model;
using ZR.Model.Dto;
using ZR.Model.Models;
using ZR.Repository;
using ZR.Service.Business.IBusinessService;
using System.Linq;
using Infrastructure;

namespace ZR.Service.Business
{
    /// <summary>
    /// 出库管理/出库记录表Service业务层处理
    ///
    /// @author admin
    /// @date 2023-04-18
    /// </summary>
    [AppService(ServiceType = typeof(IOutOutstoreRecordService), ServiceLifetime = LifeTime.Transient)]
    public class OutOutstoreRecordService : BaseService<OutOutstoreRecord>, IOutOutstoreRecordService
    {
        #region 业务逻辑代码

        /// <summary>
        /// 查询出库管理/出库记录表列表
        /// </summary>
        /// <param name="parm"></param>
        /// <returns></returns>
        public PagedInfo<OutOutstoreRecordDto> GetList(OutOutstoreRecordQueryDto parm)
        {
            //开始拼装查询条件
            var predicate = Expressionable.Create<OutOutstoreRecord>();
            if (parm.BeginTime != null && parm.EndTime != null)
            {
                parm.BeginTime = DateTimeHelper.GetBeginTime(parm.BeginTime, -1);
                parm.EndTime = DateTimeHelper.GetBeginTime(parm.EndTime, 1);
                predicate.And(it => it.CreateTime >= parm.BeginTime && it.CreateTime <= parm.EndTime);
            }
            predicate.AndIF(!string.IsNullOrEmpty(parm.OutSotreNo), it => it.OutSotreNo.Contains(parm.OutSotreNo));
            predicate.AndIF(!string.IsNullOrEmpty(parm.BomNo), it => it.BomNo.Contains(parm.BomNo));
            predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialCode), it => it.MaterialCode.Contains(parm.MaterialCode));
            predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialName), it => it.MaterialName.Contains(parm.MaterialName));
            predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialSpec), it => it.MaterialSpec.Contains(parm.MaterialSpec));
            predicate.AndIF(!string.IsNullOrEmpty(parm.BnSnCode), it => it.BnSnCode.Contains(parm.BnSnCode));
            predicate.AndIF(!string.IsNullOrEmpty(parm.Category), it => it.Category == parm.Category);
            predicate.AndIF(!string.IsNullOrEmpty(parm.CreateBy), it => it.CreateBy.Contains(parm.CreateBy));
            predicate.AndIF(parm.KeyFlag != null, it => it.KeyFlag == parm.KeyFlag);
            predicate.AndIF(parm.Result != null, it => it.Result == parm.Result);
            //搜索条件查询语法参考Sqlsugar
            var response = Queryable()
                .Where(predicate.ToExpression())
                .ToPage<OutOutstoreRecord, OutOutstoreRecordDto>(parm);

            return response;
        }


        /// <summary>
        /// 添加出库管理/出库记录表
        /// </summary>
        /// <param name="model"></param>
        /// <returns></returns>
        public int AddOutOutstoreRecord(OutOutstoreRecord model)
        {
            return Add(model, true);
        }

        /// <summary>
        /// 修改出库管理/出库记录表
        /// </summary>
        /// <param name="model"></param>
        /// <returns></returns>
        public int UpdateOutOutstoreRecord(OutOutstoreRecord model)
        {
            //var response = Update(w => w.OutStoreId == model.OutStoreId, it => new OutOutstoreRecord()
            //{
            //    OutSotreNo = model.OutSotreNo,
            //    BomNo = model.BomNo,
            //    MaterialCode = model.MaterialCode,
            //    MaterialName = model.MaterialName,
            //    MaterialSpec = model.MaterialSpec,
            //    Category = model.Category,
            //    KeyFlag = model.KeyFlag,
            //    OutStoreQty = model.OutStoreQty,
            //    Result = model.Result,
            //    UpdateBy = model.UpdateBy,
            //    UpdateTime = model.UpdateTime,
            //    Remark = model.Remark,
            //    BnSnCode = model.BnSnCode,
            //});
            //return response;
            return Update(model, true);
        }

        /// <summary>
        /// 清空出库管理/出库记录表
        /// </summary>
        /// <returns></returns>
        public void TruncateOutOutstoreRecord()
        {
            Truncate();
        }
        #endregion
    }
}